#
# spec file for package python-django-eremaea2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-django-eremaea2
Version:        2.0.18
Release:        2.1
Summary:        A simple Django application to store and show webcam snapshots
License:        BSD-2-Clause
URL:            https://github.com/matwey/django-eremaea2
Source:         https://files.pythonhosted.org/packages/source/d/django-eremaea2/django-eremaea2-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
BuildRequires:  %{python_module Django >= 1.10}
BuildRequires:  %{python_module cmdln}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module django-dj-inmemorystorage}
BuildRequires:  %{python_module djangorestframework >= 3.7.0}
BuildRequires:  %{python_module pytest-django}
# https://github.com/matwey/django-eremaea2/issues/15
BuildRequires:  %{python_module python-magic}
BuildRequires:  %{python_module requests-mock}
# https://github.com/matwey/django-eremaea2/issues/15
BuildRequires:  %{python_module requests-toolbelt}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       eremaea = %{version}
Requires:       python-Django >= 1.10
Requires:       python-cmdln
Requires:       python-djangorestframework >= 3.7.0
Requires:       python-python-magic
Requires:       python-requests
Requires:       python-requests-toolbelt
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
django-eremaea2 is a simple Django application to store and manage webcam image snapshots.
The application is built on top of django-rest-framework and provides REST API to access the files.

%package -n eremaea
Summary:        Systemd unit files for python-django-eremaea2
Group:          Development/Languages/Python
Requires:       /usr/bin/eremaeactl
%{?systemd_ordering}

%description -n eremaea
This package contains the systemd unit files for python-django-eremaea2.

%prep
%autosetup -p1 -n django-eremaea2-%{version}

%build
%python_build

%install
%python_install

for p in eremaeactl ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done

for u in eremaea-purge@.timer eremaea-purge@.service eremaea-pull@.service eremaea.target ; do
    install -D -m 0644 $u %{buildroot}%{_unitdir}/$u
done
mkdir -p %{buildroot}%{_sbindir}
ln -s service %{buildroot}%{_sbindir}/rceremaea

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=tests.test_settings
export PYTHONPATH=$(pwd)
%pytest

%post
%python_install_alternative eremaeactl

%postun
%python_uninstall_alternative eremaeactl

%pre -n eremaea
%service_add_pre eremaea.target

%post -n eremaea
%service_add_post eremaea.target

%preun -n eremaea
%service_del_preun eremaea.target

%postun -n eremaea
%service_del_postun eremaea.target

%files %{python_files}
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/eremaeactl
%{python_sitelib}/*eremaea*

%files -n eremaea
%defattr(-,root,root,-)
%license LICENSE
%{_unitdir}/eremaea-purge@.timer
%{_unitdir}/eremaea-purge@.service
%{_unitdir}/eremaea-pull@.service
%{_unitdir}/eremaea.target
%{_sbindir}/rceremaea

%changelog
* Wed Jul 12 2023 Matwey Kornilov <matwey.kornilov@gmail.com>
- Fix Requires for python-python-magic:
  correct pypi name of the required package is python-magic
  and one more python- is prepended.
* Sun May  7 2023 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 2.0.18
  - Drop Python 2.7 support
- Drop python-django-eremaea2-no-six.patch: upstreamed
* Fri Apr 28 2023 pgajdos@suse.com
- do not require python-six
- added patches
  fix https://github.com/matwey/django-eremaea2/issues/14
  + python-django-eremaea2-no-six.patch
* Tue Mar 29 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded Build-Requires on mock.
- Use pytest-django for running tests.
* Sun Dec 26 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 2.0.17
  - Fix Django4 build
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Use django-codemod to make test suite Django 4 compatible
* Tue Dec  1 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 2.0.16
  - Support HTTP Digest Auth in eremaeactl tool
* Fri Aug 28 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Version 2.0.15
  - Introduce eremaea.target to improve post/pre scripts
  - Fix build for recent djangorestframework
* Mon Feb 26 2018 matwey.kornilov@gmail.com
- Version 2.0.13
  - Style cleanups
  - Improve cache-control for collections
* Sun Dec 24 2017 matwey.kornilov@gmail.com
- Tune %%{python_module} definition
* Sun Dec 24 2017 matwey.kornilov@gmail.com
- BuildRequire: %%{pythons}
  We need sqlite3 module from standard library for tests.
* Sun Dec 24 2017 matwey.kornilov@gmail.com
- Version 2.0.12
  - Add LICENSE file to %%doc
* Sat Dec 23 2017 matwey.kornilov@gmail.com
- Add lost BuildRequires: python-rpm-macros
* Sat Dec 23 2017 matwey.kornilov@gmail.com
- Version 2.0.11
  - Support Django 2.0
* Sat Dec 23 2017 matwey.kornilov@gmail.com
- Follow openSUSE Python Singlespec
* Sun Aug  6 2017 matwey.kornilov@gmail.com
- Version 2.0.10.1
* Sun Aug  6 2017 matwey.kornilov@gmail.com
- Version 2.0.10
* Wed Aug 31 2016 matwey.kornilov@gmail.com
- Version 2.0.9
* Wed Aug 10 2016 matwey.kornilov@gmail.com
- Version 2.0.8
* Tue Jun 21 2016 matwey.kornilov@gmail.com
- Version 2.0.6:
  + Use additional prefix in MEDIA_ROOT
* Sun Apr 10 2016 matwey.kornilov@gmail.com
- Version 2.0.5
  + Fix systemd unit
* Sun Apr 10 2016 matwey.kornilov@gmail.com
- Version 2.0.4
  + Add eremaeactl control tool
* Sun Apr  3 2016 matwey.kornilov@gmail.com
- Version 2.0.2
  + Add initial Django migration
* Fri Apr  1 2016 matwey.kornilov@gmail.com
- Initial version
